@@ -61,6 +61,22 @@ void gw_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
     double F, G, L, sinG2, cosG2, sinF2, cosF2, sinL2, cosL2, S, C;
     double w, R, a, f, D, H1, H2;
     double lat1R, lat2R, lon1R, lon2R, DE2RA;
+// Maeel Le Noc bug 2017-04-12
+
+    if (fabs(lat1[0] - lat2[0]) < DOUBLE_EPS) {
+        if (fabs(lon1[0] - lon2[0]) < DOUBLE_EPS) {
+            dist[0] = 0.0;
+            return;
+/* Wouter Buytaert bug caught 100211 */
+        } else if (fabs((fabs(lon1[0]) + fabs(lon2[0])) - 360.0) < DOUBLE_EPS) {
+            dist[0] = 0.0;
+            return;
+        }
+    }
+
+/*    if (lat1[0] == lat2[0] && lon1[0] == lon2[0]) {
+      dist[0] = 0.0;
+    } else { */
     
     DE2RA = M_PI/180;
     a = 6378.137;              /* WGS-84 equatorial radius in km */
@@ -94,6 +110,7 @@ void gw_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
     H2 = ( 3*R + 1 )/( 2*S );
 
     dist[0] = D*( 1 + f*H1*sinF2*cosG2 - f*H2*cosF2*sinG2 ); 
+//    }
 
 }
 
